#******************************************************************
#
# myfpga.tcl module
#
#******************************************************************
# <Design Name>
#
# This TCL file sets up SynplifyPro, and synthesizes the FPGA design. 
# This script generates an EDIF file named: myfpga.edf.
#
#******************************************************************
project -new
set TECHNOLOGY "Virtex6"
set PART "XC6VLX195T"
set PKG "FF784"

#******************************************************************
#** Xilinx Library
#******************************************************************
add_file -verilog "$LIB/xilinx/unisim.v"
#******************************************************************
#** Top-Level Module
#******************************************************************
add_file -verilog "../../myfpga.sv"
#******************************************************************
#** Sub-Module(s)
#******************************************************************
#******************************************************************
#** Input/Output Buffers
#******************************************************************
add_file -verilog "../../in_buf/in_buf.sv"
add_file -verilog "../../out_buf/out_buf.sv"
#******************************************************************
#** Constraints
#******************************************************************
add_file -constraint "../src/myfpga.sdc"

#implementation: "rev_1"
impl -add "../log"

#implementation attributes
set_option -vlog_std sysv
set_option -project_relative_includes 1

#par_1 attributes
set_option -job par_1 -add par
set_option -job par_1 -option run_backannotation 0
impl -active "log"

#device options
set_option -technology $TECHNOLOGY
set_option -part $PART
set_option -package $PKG
set_option -speed_grade -2
set_option -part_companion ""

#compilation/mapping options
set_option -use_fsm_explorer 0
set_option -top_module "myfpga"

# mapper_options
set_option -frequency auto
set_option -write_verilog 0
set_option -write_vhdl 0

# Xilinx Virtex6
set_option -run_prop_extract 1
set_option -maxfan 10000
set_option -disable_io_insertion 0
set_option -pipe 1
set_option -update_models_cp 0
set_option -retiming 1
set_option -no_sequential_opt 0
set_option -fixgatedclocks 3
set_option -fixgeneratedclocks 3
set_option -enable_prepacking 1

# NFilter
set_option -popfeed 0
set_option -constprop 0
set_option -createhierarchy 0

# sequential_optimization_options
set_option -symbolic_fsm_compiler 1

# Compiler Options
set_option -compiler_compatible 0
set_option -resource_sharing 0

#VIF options
set_option -write_vif 1

#automatic place and route (vendor) options
set_option -write_apr_constraint 1

#set result format/file last
project -result_file "myfpga.edf"
project -log_file "../log/myfpga.srr" 
project -save "../run/myfpga.prj"
project -run

